@@ -4,7 +4,7 @@ import java.util.Collection;
 import java.util.Iterator;
 
 /**
- * A minimal String utility class. Designed for interal jsoup use only.
+ * A minimal String utility class. Designed for internal jsoup use only.
  */
 public final class StringUtil {
     // memoised padding up to 10
@@ -110,8 +110,9 @@ public final class StringUtil {
         boolean modified = false;
 
         int l = string.length();
-        for (int i = 0; i < l; i++) {
-            int c = string.codePointAt(i);
+        int c;
+        for (int i = 0; i < l; i+= Character.charCount(c)) {
+            c = string.codePointAt(i);
             if (isWhitespace(c)) {
                 if (lastWasWhite) {
                     modified = true;
