@@ -196,9 +196,9 @@ public abstract class Node implements Cloneable {
     }
 
     /**
-     Get a child node by index
+     Get a child node by its 0-based index.
      @param index index of child node
-     @return the child node at this index.
+     @return the child node at this index. Throws a {@code IndexOutOfBoundsException} if the index is out of bounds.
      */
     public Node childNode(int index) {
         return childNodes.get(index);
@@ -212,9 +212,30 @@ public abstract class Node implements Cloneable {
     public List<Node> childNodes() {
         return Collections.unmodifiableList(childNodes);
     }
+
+    /**
+     * Returns a deep copy of this node's children. Changes made to these nodes will not be reflected in the original
+     * nodes
+     * @return a deep copy of this node's children
+     */
+    public List<Node> childNodesCopy() {
+        List<Node> children = new ArrayList<Node>(childNodes.size());
+        for (Node node : childNodes) {
+            children.add(node.clone());
+        }
+        return children;
+    }
+
+    /**
+     * Get the number of child nodes that this node holds.
+     * @return the number of child nodes that this node holds.
+     */
+    public final int childNodeSize() {
+        return childNodes.size();
+    }
     
     protected Node[] childNodesAsArray() {
-        return childNodes.toArray(new Node[childNodes().size()]);
+        return childNodes.toArray(new Node[childNodeSize()]);
     }
 
     /**
@@ -247,7 +268,7 @@ public abstract class Node implements Cloneable {
     }
 
     /**
-     * Insert the specified HTML into the DOM before this node (i.e. as a preceeding sibling).
+     * Insert the specified HTML into the DOM before this node (i.e. as a preceding sibling).
      * @param html HTML to add before this node
      * @return this node, for chaining
      * @see #after(String)
@@ -258,7 +279,7 @@ public abstract class Node implements Cloneable {
     }
 
     /**
-     * Insert the specified node into the DOM before this node (i.e. as a preceeding sibling).
+     * Insert the specified node into the DOM before this node (i.e. as a preceding sibling).
      * @param node to add before this node
      * @return this node, for chaining
      * @see #after(Node)
@@ -436,11 +457,20 @@ public abstract class Node implements Cloneable {
     }
     
     /**
-     Retrieves this node's sibling nodes. Effectively, {@link #childNodes()  node.parent.childNodes()}.
-     @return node siblings, including this node
+     Retrieves this node's sibling nodes. Similar to {@link #childNodes()  node.parent.childNodes()}, but does not
+     include this node (a node is not a sibling of itself).
+     @return node siblings. If the node has no parent, returns an empty list.
      */
     public List<Node> siblingNodes() {
-        return parent().childNodes(); // TODO: should this strip out this node? i.e. not a sibling of self?
+        if (parentNode == null)
+            return Collections.emptyList();
+
+        List<Node> nodes = parentNode.childNodes;
+        List<Node> siblings = new ArrayList<Node>(nodes.size() - 1);
+        for (Node node: nodes)
+            if (node != this)
+                siblings.add(node);
+        return siblings;
     }
 
     /**
@@ -465,6 +495,9 @@ public abstract class Node implements Cloneable {
      @return the previous sibling, or null if this is the first sibling
      */
     public Node previousSibling() {
+        if (parentNode == null)
+            return null; // root
+
         List<Node> siblings = parentNode.childNodes;
         Integer index = siblingIndex();
         Validate.notNull(index);
