@@ -664,7 +664,9 @@ enum HtmlTreeBuilderState {
                             Element commonAncestor = null;
                             boolean seenFormattingElement = false;
                             LinkedList<Element> stack = tb.getStack();
-                            for (int si = 0; si < stack.size(); si++) {
+                            // the spec doesn't limit to < 64, but in degenerate cases (9000+ stack depth) this prevents
+                            // run-aways
+                            for (int si = 0; si < stack.size() && si < 64; si++) {
                                 Element el = stack.get(si);
                                 if (el == formatEl) {
                                     commonAncestor = stack.get(si - 1);
@@ -721,9 +723,9 @@ enum HtmlTreeBuilderState {
                             }
 
                             Element adopter = new Element(Tag.valueOf(name), tb.getBaseUri());
-                            Node[] childNodes = furthestBlock.childNodes().toArray(new Node[furthestBlock.childNodes().size()]);
+                            Node[] childNodes = furthestBlock.childNodes().toArray(new Node[furthestBlock.childNodeSize()]);
                             for (Node childNode : childNodes) {
-                                adopter.appendChild(childNode); // append will reparent. thus the clone to avvoid concurrent mod.
+                                adopter.appendChild(childNode); // append will reparent. thus the clone to avoid concurrent mod.
                             }
                             furthestBlock.appendChild(adopter);
                             tb.removeFromActiveFormattingElements(formatEl);
