@@ -45,19 +45,21 @@ public class Tag {
      */
     public static Tag valueOf(String tagName) {
         Validate.notNull(tagName);
-        tagName = tagName.trim().toLowerCase();
-        Validate.notEmpty(tagName);
+        Tag tag = tags.get(tagName);
+
+        if (tag == null) {
+            tagName = tagName.trim().toLowerCase();
+            Validate.notEmpty(tagName);
+            tag = tags.get(tagName);
 
-        synchronized (tags) {
-            Tag tag = tags.get(tagName);
             if (tag == null) {
                 // not defined: create default; go anywhere, do anything! (incl be inside a <p>)
                 tag = new Tag(tagName);
                 tag.isBlock = false;
                 tag.canContainBlock = true;
             }
-            return tag;
         }
+        return tag;
     }
 
     /**
@@ -108,7 +110,7 @@ public class Tag {
     /**
      * Get if this is an empty tag
      *
-     * @return if this is an emtpy tag
+     * @return if this is an empty tag
      */
     public boolean isEmpty() {
         return empty;
@@ -198,7 +200,7 @@ public class Tag {
             "html", "head", "body", "frameset", "script", "noscript", "style", "meta", "link", "title", "frame",
             "noframes", "section", "nav", "aside", "hgroup", "header", "footer", "p", "h1", "h2", "h3", "h4", "h5", "h6",
             "ul", "ol", "pre", "div", "blockquote", "hr", "address", "figure", "figcaption", "form", "fieldset", "ins",
-            "del", "dl", "dt", "dd", "li", "table", "caption", "thead", "tfoot", "tbody", "colgroup", "col", "tr", "th",
+            "del", "s", "dl", "dt", "dd", "li", "table", "caption", "thead", "tfoot", "tbody", "colgroup", "col", "tr", "th",
             "td", "video", "audio", "canvas", "details", "menu", "plaintext"
     };
     private static final String[] inlineTags = {
@@ -213,9 +215,10 @@ public class Tag {
             "device"
     };
     private static final String[] formatAsInlineTags = {
-            "title", "a", "p", "h1", "h2", "h3", "h4", "h5", "h6", "pre", "address", "li", "th", "td", "script", "style"
+            "title", "a", "p", "h1", "h2", "h3", "h4", "h5", "h6", "pre", "address", "li", "th", "td", "script", "style",
+            "ins", "del", "s"
     };
-    private static final String[] preserveWhitespaceTags = {"pre", "plaintext", "title"};
+    private static final String[] preserveWhitespaceTags = {"pre", "plaintext", "title", "textarea"};
 
     static {
         // creates
@@ -253,10 +256,7 @@ public class Tag {
         }
     }
 
-    private static Tag register(Tag tag) {
-        synchronized (tags) {
-            tags.put(tag.tagName, tag);
-        }
-        return tag;
+    private static void register(Tag tag) {
+        tags.put(tag.tagName, tag);
     }
 }
