@@ -19,6 +19,10 @@ public class Elements implements List<Element>, Cloneable {
         contents = new ArrayList<Element>();
     }
 
+    public Elements(int initialCapacity) {
+        contents = new ArrayList<Element>(initialCapacity);
+    }
+
     public Elements(Collection<Element> elements) {
         contents = new ArrayList<Element>(elements);
     }
@@ -30,7 +34,11 @@ public class Elements implements List<Element>, Cloneable {
     public Elements(Element... elements) {
         this(Arrays.asList(elements));
     }
-    
+
+    /**
+     * Creates a deep copy of these elements.
+     * @return a deep copy
+     */
     @Override
 	public Elements clone() {
     	List<Element> elements = new ArrayList<Element>();
@@ -401,7 +409,7 @@ public class Elements implements List<Element>, Cloneable {
     }
 
     /**
-     * Remove elements from this list that do not match the {@link Selector} query.
+     * Remove elements from this list that match the {@link Selector} query.
      * <p>
      * E.g. HTML: {@code <div class=logo>One</div> <div>Two</div>}<br>
      * <code>Elements divs = doc.select("div").not("#logo");</code><br>
@@ -451,7 +459,7 @@ public class Elements implements List<Element>, Cloneable {
     // list-like methods
     /**
      Get the first matched element.
-     @return The first matched element, or <code>null</code> if contents is empty;
+     @return The first matched element, or <code>null</code> if contents is empty.
      */
     public Element first() {
         return contents.isEmpty() ? null : contents.get(0);
