@@ -1,5 +1,7 @@
 package org.jsoup.integration;
 
+import org.jsoup.HttpStatusException;
+import org.jsoup.UnsupportedMimeTypeException;
 import org.junit.Test;
 import org.junit.Ignore;
 import static org.junit.Assert.*;
@@ -7,6 +9,7 @@ import org.jsoup.nodes.Document;
 import org.jsoup.Jsoup;
 import org.jsoup.Connection;
 
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.io.IOException;
 import java.util.Map;
@@ -31,10 +34,10 @@ public class UrlConnectTest {
         Connection.Response res = Jsoup.connect("http://www.baidu.com/").timeout(10*1000).execute();
         Document doc = res.parse();
 
-        assertEquals("GB2312", doc.outputSettings().charset().displayName());
-        assertEquals("GB2312", res.charset());
+        assertEquals("GBK", doc.outputSettings().charset().displayName());
+        assertEquals("GBK", res.charset());
         assert(res.hasCookie("BAIDUID"));
-        assertEquals("text/html;charset=gb2312", res.contentType());
+        assertEquals("text/html;charset=gbk", res.contentType());
     }
     
     @Test
@@ -43,8 +46,26 @@ public class UrlConnectTest {
         boolean threw = false;
         try {
             Document doc = Jsoup.parse(new URL(url), 3000);
-        } catch (IOException e) {
+        } catch (UnsupportedMimeTypeException e) {
             threw = true;
+            assertEquals("org.jsoup.UnsupportedMimeTypeException: Unhandled content type. Must be text/*, application/xml, or application/xhtml+xml. Mimetype=image/png, URL=http://jsoup.org/rez/osi_logo.png", e.toString());
+            assertEquals(url, e.getUrl());
+            assertEquals("image/png", e.getMimeType());
+        } catch (IOException e) {
+        }
+        assertTrue(threw);
+    }
+
+    @Test
+    public void exceptOnUnsupportedProtocol(){
+        String url = "file://etc/passwd";
+        boolean threw = false;
+        try {
+            Document doc = Jsoup.connect(url).get();
+        } catch (MalformedURLException e) {
+            threw = true;
+            assertEquals("java.net.MalformedURLException: Only http & https protocols supported", e.toString());
+        } catch (IOException e) {
         }
         assertTrue(threw);
     }
@@ -121,12 +142,17 @@ public class UrlConnectTest {
 
     @Test
     public void throwsExceptionOnError() {
-        Connection con = Jsoup.connect("http://infohound.net/tools/404");
+        String url = "http://direct.infohound.net/tools/404";
+        Connection con = Jsoup.connect(url);
         boolean threw = false;
         try {
             Document doc = con.get();
-        } catch (IOException e) {
+        } catch (HttpStatusException e) {
             threw = true;
+            assertEquals("org.jsoup.HttpStatusException: HTTP error fetching URL. Status=404, URL=http://direct.infohound.net/tools/404", e.toString());
+            assertEquals(url, e.getUrl());
+            assertEquals(404, e.getStatusCode());
+        } catch (IOException e) {
         }
         assertTrue(threw);
     }
@@ -137,7 +163,7 @@ public class UrlConnectTest {
         Connection.Response res = con.execute();
         Document doc = res.parse();
         assertEquals(404, res.statusCode());
-        assertEquals("Not Found", doc.select("h1").first().text());
+        assertEquals("404 Not Found", doc.select("h1").first().text());
     }
 
     @Test
@@ -183,4 +209,41 @@ public class UrlConnectTest {
         Document doc = Jsoup.connect(echoURL).cookies(cookies).get();
         assertEquals("uid=jhy; token=asdfg123", ihVal("HTTP_COOKIE", doc));
     }
+
+    @Test
+    public void handlesDodgyCharset() throws IOException {
+        // tests that when we get back "UFT8", that it is recognised as unsupported, and falls back to default instead
+        String url = "http://direct.infohound.net/tools/bad-charset.pl";
+        Connection.Response res = Jsoup.connect(url).execute();
+        assertEquals("text/html; charset=UFT8", res.header("Content-Type")); // from the header
+        assertEquals(null, res.charset()); // tried to get from header, not supported, so returns null
+        Document doc = res.parse(); // would throw an error if charset unsupported
+        assertTrue(doc.text().contains("Hello!"));
+        assertEquals("UTF-8", res.charset()); // set from default on parse
+    }
+
+    @Test
+    public void maxBodySize() throws IOException {
+        String url = "http://direct.infohound.net/tools/large.html"; // 280 K
+
+        Connection.Response defaultRes = Jsoup.connect(url).execute();
+        Connection.Response smallRes = Jsoup.connect(url).maxBodySize(50 * 1024).execute(); // crops
+        Connection.Response mediumRes = Jsoup.connect(url).maxBodySize(200 * 1024).execute(); // crops
+        Connection.Response largeRes = Jsoup.connect(url).maxBodySize(300 * 1024).execute(); // does not crop
+        Connection.Response unlimitedRes = Jsoup.connect(url).maxBodySize(0).execute();
+
+        int actualString = 280735;
+        assertEquals(actualString, defaultRes.body().length());
+        assertEquals(50 * 1024, smallRes.body().length());
+        assertEquals(200 * 1024, mediumRes.body().length());
+        assertEquals(actualString, largeRes.body().length());
+        assertEquals(actualString, unlimitedRes.body().length());
+
+        int actualDocText = 269541;
+        assertEquals(actualDocText, defaultRes.parse().text().length());
+        assertEquals(49165, smallRes.parse().text().length());
+        assertEquals(196577, mediumRes.parse().text().length());
+        assertEquals(actualDocText, largeRes.parse().text().length());
+        assertEquals(actualDocText, unlimitedRes.parse().text().length());
+    }
 }
